``sunkit-magex``
----------------

``sunkit-magex`` is a Python software package that provides a set of tools for the modelling of magnetic field data.
It is a SunPy affiliated package and is built on top of ``sunpy`` and ``astropy``.

Currently it only supports the potential field source surface (PFSS) model, but we hope to expand it to include other models in the future.

Installation
============

We recommended following the `installation guide <https://docs.sunpy.org/projects/sunkit-magex/en/latest/installing.html>`__ in the documentation.

Usage
=====

If you are new to ``sunkit-magex``, the best place to start is the `example gallery <https://docs.sunpy.org/projects/sunkit-magex/en/latest/generated/gallery/index.html>`__.

Changes
=======

See our `changelog <https://docs.sunpy.org/projects/sunkit-magex/en/latest/whatsnew/changelog.html>`__.

Getting Help
============

For more information or to ask questions about ``sunkit-magex`` or any other SunPy Project package, please check out:

-  `SunPy Chat`_
-  `SunPy mailing list <https://groups.google.com/forum/#!forum/sunpy>`__
-  `SunPy Community forum <https://community.openastronomy.org/c/sunpy/5>`__

Contributing
============

The SunPy Project is a community-driven open-source project that welcomes any and all contributions.
Whether you are a developer, student, or user, you can help by contributing code, documentation, or community support.

If you would like to get involved, the `Newcomers Guide`_ guide explains the many different ways to contribute to the SunPy Project and also shows how to get set up with a development workflow.

Help is always welcome, so come and say hello by joining the `SunPy Chat`_ and look over the `Good First Issues list`_ for the ideal places to start.

.. _Newcomers Guide: https://docs.sunpy.org/en/latest/dev_guide/contents/newcomers.html
.. _Good First Issues list: https://github.com/sunpy/sunpy/issues?q=is%3Aissue+is%3Aopen+sort%3Aupdated-desc+label%3A%22Good+First+Issue%22

Code of Conduct
===============

When you are interacting with the SunPy Community you are asked to follow our `Code of Conduct <https://sunpy.org/coc>`__.

.. _SunPy Chat: https://app.element.io/#/room/#sunpy:openastronomy.org

License
-------

This project is Copyright (c) The SunPy Community and licensed under the terms of the GNU GPL v3+ license.
This package is based upon the `Openastronomy packaging guide <https://github.com/OpenAstronomy/packaging-guide>`_ which is licensed under the BSD 3-clause license.
See the licenses folder for more information.

Contributing
------------

We love contributions! sunkit-magex is open source, built on open source, and we'd love to have you hang out in our community.

**Imposter syndrome disclaimer**: We want your help.
No, really.

There may be a little voice inside your head that is telling you that you're not ready to be an open source contributor; that your skills aren't nearly good enough to contribute.
What could you possibly offer a project like this one?

We assure you - the little voice in your head is wrong.
If you can write code at all, you can contribute code to open source.
Contributing to open source projects is a fantastic way to advance one's coding skills.
Writing perfect code isn't the measure of a good developer (that would disqualify all of us!); it's trying to create something, making mistakes, and learning from those mistakes.
That's how we all improve, and we are happy to help others learn.

Being an open source contributor doesn't just mean writing code, either.
You can help out by writing documentation, tests, or even giving feedback about the project (and yes - that includes giving feedback about the contribution process).
Some of these contributions may be the most valuable to the project as a whole, because you're coming to the project with fresh eyes, so you can see the errors and assumptions that seasoned contributors have glossed over.

Note: This disclaimer was originally written by `Adrienne Lowe <https://github.com/adriennefriend>`_ for a `PyCon talk <https://www.youtube.com/watch?v=6Uj746j9Heo>`_, and was adapted for sunkit-magex based on its use in the README file for the `MetPy project <https://github.com/Unidata/MetPy>`_.
